pub struct Decorator {
pub _type: Option<DecoratorType>,
pub offset: Option<i32>,
pub length: Option<i32>,
pub depth: Option<i32>,
}Expand description
Decorator : A decorator applied to a content string value in order to create rich text.
Fields
_type: Option<DecoratorType>offset: Option<i32>The starting character of this decorator within the content string. Use zero for the first character.
length: Option<i32>The number of content characters to alter with this decorator. Decorators such as line breaks can have zero length and fit between characters.
depth: Option<i32>The relative intensity or variation of this decorator. Decorators such as bullet-points, for example, can have multiple indentation depths.
Implementations